.. _uppsetning:

==========
Uppsetning
==========

Þú getur sett upp `korta` í gegnum Python Package Index (PyPI)
eða í gegnum kóða.

Uppsetning með `pip`::

    $ pip install korta

Uppsetning með `easy_install`,::

    $ easy_install korta

Handvirk uppsetning með kóða
---------------------------------

Ná í nýjustu útgáfu af `korta` frá
http://pypi.python.org/pypi/korta/

Handvirk uppsetning::

    $ tar xvfz korta-0.0.0.tar.gz
    $ cd korta-0.0.0
    $ python setup.py build
    # python setup.py install # með rót


Ná í þróunarútgáfu
------------------

Klóna git repóið::

    $ git clone git://github.com/StefanKjartansson/Korta.git

